server

package
v0.0.0-...-3760201 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 15, 2018 License: MIT Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func SetConfigurableProperties

func SetConfigurableProperties(cfg *config.Config)

SetConfigurableProperties invokes package specific property setters that overrides default or sets optional values based on what is in the configuration object

func SetServerProperties

func SetServerProperties(cfg *config.Config)

SetServerProperties reads cfg.Server.SSHPort and overrides the default server properties with values in the configuration json if set TODO: There must be a better way to do this?

func Start

func Start(cfg *config.Config) error

Start setups a game server

Types

This section is empty.

Jump to