Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func SetConfigurableProperties ¶
SetConfigurableProperties invokes package specific property setters that overrides default or sets optional values based on what is in the configuration object
func SetServerProperties ¶
SetServerProperties reads cfg.Server.SSHPort and overrides the default server properties with values in the configuration json if set TODO: There must be a better way to do this?
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.