Documentation
¶
Index ¶
- type Session
- func (s *Session) HandleDown()
- func (s *Session) HandleLeft()
- func (s *Session) HandleRight()
- func (s *Session) HandleSlowDown()
- func (s *Session) HandleSpeedUp()
- func (s *Session) HandleUp()
- func (s *Session) Read(p []byte) (int, error)
- func (s *Session) StartOver(worldWidth int, worldHeight int)
- func (s *Session) Write(p []byte) (int, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Session ¶
Session holds all data for a connected player
func NewSession ¶
NewSession creates a new Session
func (*Session) HandleDown ¶
func (s *Session) HandleDown()
HandleDown responds to the player pressing the down direction key
func (*Session) HandleLeft ¶
func (s *Session) HandleLeft()
HandleLeft responds to the player pressing the left direction key
func (*Session) HandleRight ¶
func (s *Session) HandleRight()
HandleRight responds to the player pressing the right direction key
func (*Session) HandleSlowDown ¶
func (s *Session) HandleSlowDown()
HandleSlowDown responds to the player pressing the SlowDown key
func (*Session) HandleSpeedUp ¶
func (s *Session) HandleSpeedUp()
HandleSpeedUp responds to the player pressing the SpeedUp key
func (*Session) HandleUp ¶
func (s *Session) HandleUp()
HandleUp responds to the player pressing the up direction key
Click to show internal directories.
Click to hide internal directories.